Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(70)

Unified Diff: webrtc/media/engine/webrtcvoiceengine.h

Issue 1974453002: Add a parameter to set a maximum filesize when starting an RTC event log on the PeerConnectionFacto… (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Fixed typo in JNI code. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/media/base/mediaengine.h ('k') | webrtc/media/engine/webrtcvoiceengine.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/media/engine/webrtcvoiceengine.h
diff --git a/webrtc/media/engine/webrtcvoiceengine.h b/webrtc/media/engine/webrtcvoiceengine.h
index 1cc550430435b4dedadd20144c0ce0c109119be0..927c21ed872d3fa5f7f63b64609dd097fedb8e0f 100644
--- a/webrtc/media/engine/webrtcvoiceengine.h
+++ b/webrtc/media/engine/webrtcvoiceengine.h
@@ -85,9 +85,10 @@ class WebRtcVoiceEngine final : public webrtc::TraceCallback {
// Stops AEC dump.
void StopAecDump();
- // Starts recording an RtcEventLog using an existing file until 10 minutes
- // pass or the StopRtcEventLog function is called.
- bool StartRtcEventLog(rtc::PlatformFile file);
+ // Starts recording an RtcEventLog using an existing file until the log file
+ // reaches the maximum filesize or the StopRtcEventLog function is called.
+ // If the value of max_size_bytes is <= 0, no limit is used.
+ bool StartRtcEventLog(rtc::PlatformFile file, int64_t max_size_bytes);
// Stops recording the RtcEventLog.
void StopRtcEventLog();
« no previous file with comments | « webrtc/media/base/mediaengine.h ('k') | webrtc/media/engine/webrtcvoiceengine.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698